==> foundation-2.6.1.tgz: package/MobileSignal/MobileSignal.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const MobileSignal = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M69.328 29.884H30.567v.01a2.495 2.495 0 00-2.396 2.49v59.967a2.495 2.495 0 002.396 2.489v.011h38.761a2.5 2.5 0 002.5-2.5V32.384a2.5 2.5 0 00-2.5-2.5zM50.059 92.268a2.45 2.45 0 110-4.9 2.45 2.45 0 010 4.9zm11.813-7.396H38.128V39.84h23.743v45.032z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M69.603 15.696a1.488 1.488 0 00-.006-1.85l.024-.024-.999-.999-.001-.001-.078-.078-.004.004c-10.238-10.154-26.825-10.132-37.032.073-.015.015-.019.036-.034.051l-.008-.008-.955.955-.003.002-.002.003-.118.119.024.024a1.502 1.502 0 00.08 1.979l-.004.004 1.918 1.918.026-.026c.55.428 1.303.427 1.85-.006l.025.024 1.079-1.078-.022-.022c.015-.015.036-.019.051-.034 8.053-8.052 21.135-8.074 29.221-.075l-.009.009.956.957v.001h.001l.12.121.024-.024a1.503 1.503 0 001.979-.079l.004.004.021-.021h.001v-.001L69.5 15.85l.128-.128-.025-.026z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M62.208 21.235l.024-.024-1.079-1.079-.004.004c-6.165-6.078-16.12-6.054-22.251.076-.015.015-.019.035-.033.05l-.009-.008-1.079 1.079.024.024a1.501 1.501 0 00.079 1.979l-.004.004 1.918 1.918.026-.026c.55.428 1.303.427 1.85-.006l.025.025 1.079-1.078-.022-.022c.015-.015.036-.019.051-.034 3.977-3.977 10.425-3.995 14.436-.072l-.005.005.957.957h.001l.121.121.024-.025a1.503 1.503 0 001.979-.079l.004.004.021-.021 1.897-1.897-.026-.026a1.484 1.484 0 00-.004-1.849z"
  }));
});
MobileSignal.displayName = 'MobileSignal';
export const MobileSignalDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/MobileSignal/MobileSignal.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var MobileSignal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M69.328 29.884H30.567v.01a2.495 2.495 0 00-2.396 2.49v59.967a2.495 2.495 0 002.396 2.489v.011h38.761a2.5 2.5 0 002.5-2.5V32.384a2.5 2.5 0 00-2.5-2.5zM50.059 92.268a2.45 2.45 0 110-4.9 2.45 2.45 0 010 4.9zm11.813-7.396H38.128V39.84h23.743v45.032z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M69.603 15.696a1.488 1.488 0 00-.006-1.85l.024-.024-.999-.999-.001-.001-.078-.078-.004.004c-10.238-10.154-26.825-10.132-37.032.073-.015.015-.019.036-.034.051l-.008-.008-.955.955-.003.002-.002.003-.118.119.024.024a1.502 1.502 0 00.08 1.979l-.004.004 1.918 1.918.026-.026c.55.428 1.303.427 1.85-.006l.025.024 1.079-1.078-.022-.022c.015-.015.036-.019.051-.034 8.053-8.052 21.135-8.074 29.221-.075l-.009.009.956.957v.001h.001l.12.121.024-.024a1.503 1.503 0 001.979-.079l.004.004.021-.021h.001v-.001L69.5 15.85l.128-.128-.025-.026z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M62.208 21.235l.024-.024-1.079-1.079-.004.004c-6.165-6.078-16.12-6.054-22.251.076-.015.015-.019.035-.033.05l-.009-.008-1.079 1.079.024.024a1.501 1.501 0 00.079 1.979l-.004.004 1.918 1.918.026-.026c.55.428 1.303.427 1.85-.006l.025.025 1.079-1.078-.022-.022c.015-.015.036-.019.051-.034 3.977-3.977 10.425-3.995 14.436-.072l-.005.005.957.957h.001l.121.121.024-.025a1.503 1.503 0 001.979-.079l.004.004.021-.021 1.897-1.897-.026-.026a1.484 1.484 0 00-.004-1.849z"
  }));
});
MobileSignal.displayName = 'MobileSignal';
export var MobileSignalDimensions = {
  height: 100,
  width: 100
};
